#define DECLARE_TEXTURE(Name, index) \
    texture Name: register(t##index); \
    sampler Name##Sampler: register(s##index)

#define SAMPLE_TEXTURE(Name, texCoord) tex2D(Name##Sampler, texCoord)

uniform float Time; // level.TimeActive
uniform float2 CamPos; // level.Camera.Position
uniform float2 Dimensions; // new Vector2(320, 180)

uniform float4x4 TransformMatrix;
uniform float4x4 ViewMatrix;

DECLARE_TEXTURE(text, 0);

float4 SpritePixelShader(float2 uv : TEXCOORD0) : COLOR0
{
    float2 worldPos = (uv * Dimensions) + CamPos;
    float4 color = SAMPLE_TEXTURE(text, uv);

    float2 vu = float2(uv.x,1.-uv.y);

    float noiseX = (frac(sin(dot(uv.x, float2(12.9898 * Time,78.233)      )) * 43758.5453));
    float noiseY = (frac(sin(dot(uv.y, float2(12.9898 * Time,78.233) * 2.0)) * 43758.5453));

    float threshhold = 0.1;
    if(color.r > threshhold && color.g > threshhold && color.b > threshhold)
    {
        return float4(noiseY,noiseY,noiseY,1.0);
    }
    return float4(noiseX,noiseX,noiseX,1.0);
}

void SpriteVertexShader(inout float4 color    : COLOR0,
                        inout float2 texCoord : TEXCOORD0,
                        inout float4 position : SV_Position)
{
    position = mul(position, ViewMatrix);
    position = mul(position, TransformMatrix);
}

technique Shader
{
    pass pass0
    {
        VertexShader = compile vs_3_0 SpriteVertexShader();
        PixelShader = compile ps_3_0 SpritePixelShader();
    }
}